@@ -101,17 +101,17 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import constructs
+import constructs as _constructs_77d1e7e8
 
 
 class BudgetNotifier(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="aws_budget_notifier.BudgetNotifier",
 ):
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         limit: jsii.Number,
@@ -142,24 +142,7 @@ class BudgetNotifier(
         :param topic_arn: 
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                limit: jsii.Number,
-                threshold: jsii.Number,
-                unit: builtins.str,
-                application: typing.Optional[builtins.str] = None,
-                availability_zones: typing.Optional[typing.Sequence[builtins.str]] = None,
-                cost_center: typing.Optional[builtins.str] = None,
-                notification_type: typing.Optional[NotificationType] = None,
-                recipients: typing.Optional[typing.Sequence[builtins.str]] = None,
-                service: typing.Optional[builtins.str] = None,
-                time_unit: typing.Optional[TimeUnit] = None,
-                topic_arn: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__84bfc8e2612536ca8c70cc5d518a5393c60beee341db21121d3852d4a886c318)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = BudgetNotifierProps(
@@ -227,22 +210,7 @@ class BudgetNotifierProps:
         :param topic_arn: 
         '''
         if __debug__:
-            def stub(
-                *,
-                limit: jsii.Number,
-                threshold: jsii.Number,
-                unit: builtins.str,
-                application: typing.Optional[builtins.str] = None,
-                availability_zones: typing.Optional[typing.Sequence[builtins.str]] = None,
-                cost_center: typing.Optional[builtins.str] = None,
-                notification_type: typing.Optional[NotificationType] = None,
-                recipients: typing.Optional[typing.Sequence[builtins.str]] = None,
-                service: typing.Optional[builtins.str] = None,
-                time_unit: typing.Optional[TimeUnit] = None,
-                topic_arn: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__21f73a16710abede15940126a33e196b183fc8727121ec667cf4e27b7727d842)
             check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
             check_type(argname="argument threshold", value=threshold, expected_type=type_hints["threshold"])
             check_type(argname="argument unit", value=unit, expected_type=type_hints["unit"])
@@ -254,7 +222,7 @@ class BudgetNotifierProps:
             check_type(argname="argument service", value=service, expected_type=type_hints["service"])
             check_type(argname="argument time_unit", value=time_unit, expected_type=type_hints["time_unit"])
             check_type(argname="argument topic_arn", value=topic_arn, expected_type=type_hints["topic_arn"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "limit": limit,
             "threshold": threshold,
             "unit": unit,
@@ -386,3 +354,39 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__84bfc8e2612536ca8c70cc5d518a5393c60beee341db21121d3852d4a886c318(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    limit: jsii.Number,
+    threshold: jsii.Number,
+    unit: builtins.str,
+    application: typing.Optional[builtins.str] = None,
+    availability_zones: typing.Optional[typing.Sequence[builtins.str]] = None,
+    cost_center: typing.Optional[builtins.str] = None,
+    notification_type: typing.Optional[NotificationType] = None,
+    recipients: typing.Optional[typing.Sequence[builtins.str]] = None,
+    service: typing.Optional[builtins.str] = None,
+    time_unit: typing.Optional[TimeUnit] = None,
+    topic_arn: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__21f73a16710abede15940126a33e196b183fc8727121ec667cf4e27b7727d842(
+    *,
+    limit: jsii.Number,
+    threshold: jsii.Number,
+    unit: builtins.str,
+    application: typing.Optional[builtins.str] = None,
+    availability_zones: typing.Optional[typing.Sequence[builtins.str]] = None,
+    cost_center: typing.Optional[builtins.str] = None,
+    notification_type: typing.Optional[NotificationType] = None,
+    recipients: typing.Optional[typing.Sequence[builtins.str]] = None,
+    service: typing.Optional[builtins.str] = None,
+    time_unit: typing.Optional[TimeUnit] = None,
+    topic_arn: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
